summaryrefslogtreecommitdiffstats
path: root/filters/kpresenter/ooimpress
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /filters/kpresenter/ooimpress
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'filters/kpresenter/ooimpress')
-rw-r--r--filters/kpresenter/ooimpress/ooimpressexport.h2
-rw-r--r--filters/kpresenter/ooimpress/ooimpressimport.cc18
-rw-r--r--filters/kpresenter/ooimpress/ooimpressimport.h4
-rw-r--r--filters/kpresenter/ooimpress/stylefactory.cc2
4 files changed, 13 insertions, 13 deletions
diff --git a/filters/kpresenter/ooimpress/ooimpressexport.h b/filters/kpresenter/ooimpress/ooimpressexport.h
index 3b1e7b79..ac369192 100644
--- a/filters/kpresenter/ooimpress/ooimpressexport.h
+++ b/filters/kpresenter/ooimpress/ooimpressexport.h
@@ -34,7 +34,7 @@ class OoImpressExport : public KoFilter
Q_OBJECT
TQ_OBJECT
public:
- OoImpressExport( KoFilter * tqparent, const char * name, const TQStringList & );
+ OoImpressExport( KoFilter * parent, const char * name, const TQStringList & );
virtual ~OoImpressExport();
virtual KoFilter::ConversiontqStatus convert( const TQCString & from,
diff --git a/filters/kpresenter/ooimpress/ooimpressimport.h b/filters/kpresenter/ooimpress/ooimpressimport.h
index 26d49420..596ca703 100644
--- a/filters/kpresenter/ooimpress/ooimpressimport.h
+++ b/filters/kpresenter/ooimpress/ooimpressimport.h
@@ -43,7 +43,7 @@ class OoImpressImport : public KoFilter
Q_OBJECT
TQ_OBJECT
public:
- OoImpressImport( KoFilter * tqparent, const char * name, const TQStringList & );
+ OoImpressImport( KoFilter * parent, const char * name, const TQStringList & );
virtual ~OoImpressImport();
virtual KoFilter::ConversiontqStatus convert( TQCString const & from, TQCString const & to );
@@ -91,7 +91,7 @@ private:
void parseList( TQDomDocument& doc, TQDomElement& textObjectElement, const TQDomElement& list );
void parseParagraphs( TQDomDocument& doc, TQDomElement& textObjectElement, const TQDomElement& textBox );
TQDomElement parseParagraph( TQDomDocument& doc, const TQDomElement& paragraph );
- void parseSpanOrSimilar( TQDomDocument& doc, const TQDomElement& tqparent,
+ void parseSpanOrSimilar( TQDomDocument& doc, const TQDomElement& parent,
TQDomElement& outputParagraph, uint& pos);
bool parseSettings( TQDomDocument &doc, TQDomElement &helpLineElement, TQDomElement &attributeElement );
void parseHelpLine( TQDomDocument &doc,TQDomElement &helpLineElement, const TQString &text );
diff --git a/filters/kpresenter/ooimpress/stylefactory.cc b/filters/kpresenter/ooimpress/stylefactory.cc
index 18ce339b..a25ba52a 100644
--- a/filters/kpresenter/ooimpress/stylefactory.cc
+++ b/filters/kpresenter/ooimpress/stylefactory.cc
@@ -1208,7 +1208,7 @@ void GraphicStyle::toXML( TQDomDocument & doc, TQDomElement & e ) const
style.setAttribute( "style:name", m_name );
style.setAttribute( "style:family", "graphics" );
if ( m_name != "standard" )
- style.setAttribute( "style:tqparent-style-name", "standard" );
+ style.setAttribute( "style:parent-style-name", "standard" );
TQDomElement properties = doc.createElement( "style:properties" );
if ( !m_stroke.isNull() )
diff --git a/filters/kpresenter/ooimpress/ooimpressimport.cc b/filters/kpresenter/ooimpress/ooimpressimport.cc
index cf853dea..1dab566d 100644
--- a/filters/kpresenter/ooimpress/ooimpressimport.cc
+++ b/filters/kpresenter/ooimpress/ooimpressimport.cc
@@ -1517,10 +1517,10 @@ TQDomElement OoImpressImport::parseTextBox( TQDomDocument& doc, const TQDomEleme
return textObjectElement;
}
-void OoImpressImport::parseParagraphs( TQDomDocument& doc, TQDomElement& textObjectElement, const TQDomElement& tqparent )
+void OoImpressImport::parseParagraphs( TQDomDocument& doc, TQDomElement& textObjectElement, const TQDomElement& parent )
{
TQDomElement t;
- forEachElement( t, tqparent )
+ forEachElement( t, parent )
{
m_styleStack.save();
const TQString localName = t.localName();
@@ -1707,12 +1707,12 @@ TQDomElement OoImpressImport::parseParagraph( TQDomDocument& doc, const TQDomEle
return p;
}
-void OoImpressImport::parseSpanOrSimilar( TQDomDocument& doc, const TQDomElement& tqparent,
+void OoImpressImport::parseSpanOrSimilar( TQDomDocument& doc, const TQDomElement& parent,
TQDomElement& outputParagraph, uint& pos)
{
// Parse every child node of the tqparent
// Can't use forEachElement here since we also care about text nodes
- for( TQDomNode node = tqparent.firstChild(); !node.isNull(); node = node.nextSibling() )
+ for( TQDomNode node = parent.firstChild(); !node.isNull(); node = node.nextSibling() )
{
TQDomElement ts = node.toElement();
TQString textData;
@@ -2029,11 +2029,11 @@ void OoImpressImport::fillStyleStack( const TQDomElement& object, bool sticky )
void OoImpressImport::addStyles( const TQDomElement* style )
{
kdDebug(30518)<<" addStyle :" << style->attributeNS( ooNS::style, "name", TQString() ) <<endl;
- // this function is necessary as tqparent styles can have parents themself
- if ( style->hasAttributeNS( ooNS::style, "tqparent-style-name" ) )
+ // this function is necessary as parent styles can have parents themself
+ if ( style->hasAttributeNS( ooNS::style, "parent-style-name" ) )
{
- //kdDebug(30518)<<"m_styles[style->attribute( style:tqparent-style-name )] :"<<m_styles[style->attributeNS( ooNS::style, "tqparent-style-name", TQString() )]<<endl;
- addStyles( m_styles[style->attributeNS( ooNS::style, "tqparent-style-name", TQString() )] );
+ //kdDebug(30518)<<"m_styles[style->attribute( style:parent-style-name )] :"<<m_styles[style->attributeNS( ooNS::style, "parent-style-name", TQString() )]<<endl;
+ addStyles( m_styles[style->attributeNS( ooNS::style, "parent-style-name", TQString() )] );
}
//kdDebug(30518)<<" void OoImpressImport::addStyles( const TQDomElement* style ) :"<<style<<endl;
m_styleStack.push( *style );
@@ -1707,12 +1707,12 @@ TQDomElement OoImpressImport::parseParagraph( TQDomDocument& doc, const TQDomEle
TQDomElement& outputParagraph, uint& pos)
{
- // Parse every child node of the tqparent
+ // Parse every child node of the parent
// Can't use forEachElement here since we also care about text nodes